@@ -167,6 +167,17 @@ pub struct Properties {
     pub properties: HashMap<String, PropertyValue>,
 }
 
+impl Properties {
+    pub fn title(&self) -> Option<String> {
+        self.properties.values().find_map(|p| match p {
+            PropertyValue::Title { title, .. } => {
+                Some(title.into_iter().map(|t| t.plain_text()).collect())
+            }
+            _ => None,
+        })
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Eq, PartialEq, Clone)]
 pub struct Page {
     pub id: PageId,
@@ -180,6 +191,12 @@ pub struct Page {
     pub parent: Parent,
 }
 
+impl Page {
+    pub fn title(&self) -> Option<String> {
+        self.properties.title()
+    }
+}
+
 #[derive(Serialize, Deserialize, Debug, Eq, PartialEq, Clone)]
 pub struct BlockCommon {
     pub id: BlockId,
